Crate oxml_core

Crate oxml_core 

Format-neutral OOXML primitives.

Re-exports

pub use error::OxmlError;
pub use error::Result;
pub use units::Emu;
pub use units::HalfPoint;
pub use units::Twips;

Modules

app_properties
Application-specific properties from docProps/app.xml.
core_properties
Dublin Core metadata from docProps/core.xml.
custom_properties
Custom properties from docProps/custom.xml.
error
Error types for OXML parsing.
raw_xml
Raw XML capture utilities for preserving unknown elements during round-trip.
units
Unit types for OOXML measurements.
xml
Shared OOXML namespace and attribute helpers.
xml_text
Helpers for turning quick-xml text events into plain Rust strings.

Structs

Length
A length measurement that can be expressed in various units.