Raw XML capture utilities for preserving unknown elements during round-trip.
Functions
- capture_
element - Capture a full XML subtree (from after the start tag through the matching end tag) and return it as raw bytes. The returned bytes include the start tag, all children, and the end tag.
- capture_
empty_ element - Capture an empty (self-closing) element as raw bytes.