capture_element

Function capture_element 

pub fn capture_element(
    reader: &mut Reader<&[u8]>,
    start: &BytesStart<'_>,
) -> Result<Vec<u8>>
Capture a full XML subtree (from after the start tag through the matching end tag) and return it as raw bytes. The returned bytes include the start tag, all children, and the end tag.