Module xml

Module xml 

Shared OOXML namespace and attribute helpers.

Constants

MC_NS
Markup Compatibility namespace.
R_NS
Relationships namespace.

Functions

get_attr
Return a named attribute value, matching with or without a prefix.
local_name
Return the local portion of a possibly prefixed XML name.
matches_local_name
Check whether an XML name has the expected local portion.