pub fn get_attr(element: &BytesStart<'_>, name: &[u8]) -> Option<String>Expand description
Return a named attribute value, matching with or without a prefix.
pub fn get_attr(element: &BytesStart<'_>, name: &[u8]) -> Option<String>Return a named attribute value, matching with or without a prefix.